==> order-center-api-3.2.2-CLOUD-DEV-20240507.070101-9-sources.jar: com/tydic/dyc/oc/service/domainservice/bo/UocSaleShipOrderReqBo.java <==
package com.tydic.dyc.oc.service.domainservice.bo;

import com.tydic.dyc.base.bo.BaseReqBo;
import com.tydic.dyc.oc.service.common.bo.UocBaseExtParallelBo;
import com.tydic.dyc.oc.service.common.bo.UocBaseOrderAccessoryAddBo;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.EqualsAndHashCode;

import java.util.Date;
import java.util.List;

/**
 * 描述: 〈领域服务-发货（基于销售单）入参〉
 * @author : yuhao
 * @date : 2022/8/23 16:58
 */
@Data
@EqualsAndHashCode(callSuper=false)
public class UocSaleShipOrderReqBo extends BaseReqBo {
    private static final long serialVersionUID = -5637207939037461261L;

    /**
    * 订单ID
    **/
    private Long orderId;

    /**
    * 销售单ID
    * */
    private Long saleOrderId;

    /**
    * 环节编码
    * */
    private String tacheCode;

    /**
    * 发货单类型
    * */
    private Integer shipOrderType;

    /**
    * 物流公司id
    * */
    private String shipCompanyId;

    /**
    * 物流公司名称
    * */
    private String shipCompanyName;

    /**
    * 物流单号
    * */
    private String shipCompanyNo;

    /**
    * 车牌号
    * */
    private String carNo;

    /**
    * 运输方式
    * */
    private Integer transportMode;

    /**
    * 发货时间
    * */
    private Date shipTime;

    /**
    * 发货联系人姓名
    * */
    private String shipName;

    /**
    * 发货联系人电话
    * */
    private String shipPhone;

    /**
    * 预计到货时间
    * */
    private Date estimateArrivalTime;

    /**
    * 发货备注
    * */
    private String shipRemark;

    /**
    * 纵向扩展数据
    * */
    private List<UocBaseExtParallelBo> extParallelBoList;

    /**
    * 发货单集合
    * */
    private List<UocSaleShipOrderBo> shipOrderBoList;
    
    /**
    * 附件
    * */
    private List<UocBaseOrderAccessoryAddBo> orderAccessoryBoList;

    /**
    * 会员信息：用户id
    * */
    private Long userId;

    /**
    * 会员信息：供应商ID
    * */
    private Long supId;
}

==> order-center-api-3.2.3-CLOUD-DEV-20241125.054658-24-sources.jar: com/tydic/dyc/oc/service/domainservice/bo/UocSaleShipOrderReqBo.java <==
package com.tydic.dyc.oc.service.domainservice.bo;

import com.tydic.dyc.base.bo.BaseReqBo;
import com.tydic.dyc.oc.service.common.bo.UocBaseExtParallelBo;
import com.tydic.dyc.oc.service.common.bo.UocBaseOrderAccessoryAddBo;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.EqualsAndHashCode;

import java.util.Date;
import java.util.List;

/**
 * 描述: 〈领域服务-发货（基于销售单）入参〉
 * @author : yuhao
 * @date : 2022/8/23 16:58
 */
@Data
@EqualsAndHashCode(callSuper=false)
public class UocSaleShipOrderReqBo extends BaseReqBo {
    private static final long serialVersionUID = -5637207939037461261L;

    /**
    * 订单ID
    **/
    private Long orderId;

    /**
    * 销售单ID
    * */
    private Long saleOrderId;

    /**
    * 环节编码
    * */
    private String tacheCode;

    /**
    * 发货单类型
    * */
    private Integer shipOrderType;

    /**
    * 物流公司id
    * */
    private String shipCompanyId;

    /**
    * 物流公司名称
    * */
    private String shipCompanyName;

    /**
    * 物流单号
    * */
    private String shipCompanyNo;

    /**
    * 车牌号
    * */
    private String carNo;

    /**
    * 运输方式
    * */
    private Integer transportMode;

    /**
    * 发货时间
    * */
    private Date shipTime;

    /**
    * 发货联系人姓名
    * */
    private String shipName;

    /**
    * 发货联系人电话
    * */
    private String shipPhone;

    /**
    * 预计到货时间
    * */
    private Date estimateArrivalTime;

    /**
    * 发货备注
    * */
    private String shipRemark;

    /**
    * 纵向扩展数据
    * */
    private List<UocBaseExtParallelBo> extParallelBoList;

    /**
    * 发货明细
    * */
    private List<UocSaleShipOrderReqItemBo> shipOrderItemBoList;
    
    /**
    * 附件
    * */
    private List<UocBaseOrderAccessoryAddBo> orderAccessoryBoList;

    /**
    * 会员信息：用户id
    * */
    private Long userId;

    /**
    * 会员信息：供应商ID
    * */
    private Long supId;

    /**
     * 司机姓名
     */
    private String driverName;

    /**
     * 司机电话
     */
    private String driverPhone;

}
